/**
 * grunt-qunit-blanket-lcov
 * https://github.com/mistic100/grunt-qunit-blanket-lcov
 *
 * Copyright (c) 2015-2017 Damien "Mistic" Sorel
 * Licensed under the MIT license.
 */

"use strict";

var path = require('path');

module.exports = function(grunt) {

    grunt.registerMultiTask('qunit_blanket_lcov', 'Save LCOV reports generated by Blanket for Grunt QUnit.', function() {
        var options = this.options({
            dest: null,
            prefix: null,
            inject_reporter: true,
            force: false
        });

        if (!options.dest) {
            grunt.log.error('No destination file provided to qunit-blanket-lcov');
            return;
        }

        if (!options.prefix) {
            grunt.log.error('No prefix configured for qunit-blanket-lcov');
            return;
        }

        if (grunt.file.exists(options.dest)) {
            grunt.file.delete(options.dest);
        }

        if (options.inject_reporter) {
            grunt.config.merge({
                qunit: {
                    options: {
                        inject: [
                            path.join(__dirname, '../../grunt-contrib-qunit/phantomjs/bridge.js'),
                            path.join(__dirname, '../reporter.js')
                        ]
                    }
                }
            });
        }

        var files = {};
        this.files.forEach(function(file) {
            files[file.src[0]] = true;
        });

        grunt.event.on('qunit.report', function(data) {
            var str = '';

            for (var file in data) {
                var cleanFile = file.replace(options.prefix, '');

                if (files[cleanFile]) {
                    grunt.verbose.writeln('Received coverage results for ' + cleanFile);

                    str += 'SF:' + cleanFile + '\n';

                    data[file].forEach(function(val, line) {
                        if (val !== undefined && val !== null) {
                            str += 'DA:' + line + ',' + val + '\n';
                        }
                    });

                    str += 'end_of_record\n';
                }
            }

            if (str.length) {
                grunt.file.write(options.dest, str);
                grunt.log.ok('LCOV file created');
            }
            else if (options.force) {
                grunt.log.error('Empty coverage results');
            }
            else {
                grunt.fail.warn('Empty coverage results');
            }
        });
    });

};
